==> zio-aws-rds_2.12-5.17.125.1-sources.jar: zio/aws/rds/model/DescribeOrderableDbInstanceOptionsRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.{IntegerOptional, BooleanOptional}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeOrderableDbInstanceOptionsRequest(
    engine: String,
    engineVersion: scala.Option[String] = None,
    dbInstanceClass: scala.Option[String] = None,
    licenseModel: scala.Option[String] = None,
    availabilityZoneGroup: scala.Option[String] = None,
    vpc: scala.Option[BooleanOptional] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest = {
    import DescribeOrderableDbInstanceOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
      .builder()
      .engine(engine: java.lang.String)
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(dbInstanceClass.map(value => value: java.lang.String))(
        _.dbInstanceClass
      )
      .optionallyWith(licenseModel.map(value => value: java.lang.String))(
        _.licenseModel
      )
      .optionallyWith(
        availabilityZoneGroup.map(value => value: java.lang.String)
      )(_.availabilityZoneGroup)
      .optionallyWith(
        vpc.map(value => BooleanOptional.unwrap(value): java.lang.Boolean)
      )(_.vpc)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxRecords.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest.ReadOnly =
    zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest
      .wrap(buildAwsValue())
}
object DescribeOrderableDbInstanceOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest =
      zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest(
        engine,
        engineVersion.map(value => value),
        dbInstanceClass.map(value => value),
        licenseModel.map(value => value),
        availabilityZoneGroup.map(value => value),
        vpc.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def engine: String
    def engineVersion: scala.Option[String]
    def dbInstanceClass: scala.Option[String]
    def licenseModel: scala.Option[String]
    def availabilityZoneGroup: scala.Option[String]
    def vpc: scala.Option[BooleanOptional]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getEngine: ZIO[Any, Nothing, String] = ZIO.succeed(engine)
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getDbInstanceClass: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbInstanceClass", dbInstanceClass)
    def getLicenseModel: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("licenseModel", licenseModel)
    def getAvailabilityZoneGroup: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("availabilityZoneGroup", availabilityZoneGroup)
    def getVpc: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("vpc", vpc)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
  ) extends zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest.ReadOnly {
    override val engine: String = impl.engine(): String
    override val engineVersion: scala.Option[String] =
      scala.Option(impl.engineVersion()).map(value => value: String)
    override val dbInstanceClass: scala.Option[String] =
      scala.Option(impl.dbInstanceClass()).map(value => value: String)
    override val licenseModel: scala.Option[String] =
      scala.Option(impl.licenseModel()).map(value => value: String)
    override val availabilityZoneGroup: scala.Option[String] =
      scala.Option(impl.availabilityZoneGroup()).map(value => value: String)
    override val vpc: scala.Option[BooleanOptional] = scala
      .Option(impl.vpc())
      .map(value => zio.aws.rds.model.primitives.BooleanOptional(value))
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] = scala
      .Option(impl.maxRecords())
      .map(value => zio.aws.rds.model.primitives.IntegerOptional(value))
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
  ): zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.155.2-sources.jar: zio/aws/rds/model/DescribeOrderableDbInstanceOptionsRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.{IntegerOptional, BooleanOptional}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeOrderableDbInstanceOptionsRequest(
    engine: String,
    engineVersion: scala.Option[String] = None,
    dbInstanceClass: scala.Option[String] = None,
    licenseModel: scala.Option[String] = None,
    availabilityZoneGroup: scala.Option[String] = None,
    vpc: scala.Option[BooleanOptional] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest = {
    import DescribeOrderableDbInstanceOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
      .builder()
      .engine(engine: java.lang.String)
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(dbInstanceClass.map(value => value: java.lang.String))(
        _.dbInstanceClass
      )
      .optionallyWith(licenseModel.map(value => value: java.lang.String))(
        _.licenseModel
      )
      .optionallyWith(
        availabilityZoneGroup.map(value => value: java.lang.String)
      )(_.availabilityZoneGroup)
      .optionallyWith(vpc.map(value => value: java.lang.Boolean))(_.vpc)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest.ReadOnly =
    zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest
      .wrap(buildAwsValue())
}
object DescribeOrderableDbInstanceOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest =
      zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest(
        engine,
        engineVersion.map(value => value),
        dbInstanceClass.map(value => value),
        licenseModel.map(value => value),
        availabilityZoneGroup.map(value => value),
        vpc.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def engine: String
    def engineVersion: scala.Option[String]
    def dbInstanceClass: scala.Option[String]
    def licenseModel: scala.Option[String]
    def availabilityZoneGroup: scala.Option[String]
    def vpc: scala.Option[BooleanOptional]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getEngine: ZIO[Any, Nothing, String] = ZIO.succeed(engine)
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getDbInstanceClass: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbInstanceClass", dbInstanceClass)
    def getLicenseModel: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("licenseModel", licenseModel)
    def getAvailabilityZoneGroup: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("availabilityZoneGroup", availabilityZoneGroup)
    def getVpc: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("vpc", vpc)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
  ) extends zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest.ReadOnly {
    override val engine: String = impl.engine(): String
    override val engineVersion: scala.Option[String] =
      scala.Option(impl.engineVersion()).map(value => value: String)
    override val dbInstanceClass: scala.Option[String] =
      scala.Option(impl.dbInstanceClass()).map(value => value: String)
    override val licenseModel: scala.Option[String] =
      scala.Option(impl.licenseModel()).map(value => value: String)
    override val availabilityZoneGroup: scala.Option[String] =
      scala.Option(impl.availabilityZoneGroup()).map(value => value: String)
    override val vpc: scala.Option[BooleanOptional] =
      scala.Option(impl.vpc()).map(value => value: BooleanOptional)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] =
      scala.Option(impl.maxRecords()).map(value => value: IntegerOptional)
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeOrderableDbInstanceOptionsRequest
  ): zio.aws.rds.model.DescribeOrderableDbInstanceOptionsRequest.ReadOnly =
    new Wrapper(impl)
}
